==> junitperf_1.6.orig.tar.gz: junitperf-1.6.orig/src/app/com/clarkware/junitperf/TestFactory.java <==
package com.clarkware.junitperf;

import junit.framework.Test;
import junit.framework.TestCase;
import junit.framework.TestResult;
import junit.framework.TestSuite;

/**
 * The <code>TestFactory</code> class creates thread-local 
 * <code>TestSuite</code> instances.
 * <p>
 * This factory class should be used in cases when a stateful test
 * is intended to be decorated by a <code>LoadTest</code>.  A stateful
 * test is defined as any test that defines test-specific state in
 * its <code>setUp()</code> method.
 * <p>
 * Use of the <code>TestFactory</code> ensures that each thread spawned
 * by a <code>LoadTest</code> contains its own <code>TestSuite</code>
 * containing all tests defined in the specified <code>TestCase</code>
 * class.
 * <p>
 * A typical usage scenario is as follows:
 * <blockquote>
 * <pre>
 * Test testFactory = new TestFactory(YourTestCase.class);
 * LoadTest test = new LoadTest(testFactory, number_of_users, ...);
 * ...
 * </pre>
 * </blockquote>
 * <p>
 * Of course, static variables cannot be protected externally, so tests
 * intended to be run in a multithreaded environment should ensure
 * that the use of static variables is thread-safe.
 * <p>
 * This class is dependent on Java 2.  For earlier platforms a 
 * local cache implementation should be changed to use, for example, 
 * a HashMap to track thread-local information.
 * 
 * @author <a href="mailto:mike@clarkware.com">Mike Clark</a>
 * @author <a href="http://www.clarkware.com">Clarkware Consulting, Inc.</a>
 * @author Ervin Varga
 *
 * @see junit.framework.Test
 * @see com.clarkware.junitperf.LoadTest
 */

public class TestFactory implements Test {
    
	private final Class _testClass;
	private final TestSuite _suite; 
	private final TestCache _testCache;
    
	/**
	 * Constructs a <code>TestFactory</code> instances.
	 *
	 * @param testClass The <code>TestCase</code> class to 
	 *                  be run by multiple threads.
	 */
	public TestFactory(Class testClass) {

		if (!(TestCase.class.isAssignableFrom(testClass))) {
			throw new IllegalArgumentException("TestFactory must " +
				"be constructed with a TestCase class.");
		}
		
		_suite = new TestSuite(testClass);
		_testClass = testClass;
		_testCache = new TestCache();
	}

	/**
	 * Runs an instance of the <code>Test</code> class and 
	 * collects its result in the specified <code>TestResult</code>. 
	 * <p>
	 * Each invocation of this method triggers the creation of a 
	 * new <code>Test</code> class instance as specified in the
	 * construction of this <code>TestFactory</code>.
	 *
	 * @param result Test result.
	 */
	public void run(TestResult result) {
		_testCache.getTest().run(result);        
	}
    
	/**
	 * Returns the number of tests in this test.
	 *
	 * @return Number of tests.
	 */
	public int countTestCases() {
		return _suite.countTestCases();
	}

	/**
	 * Returns the test description.
	 *
	 * @return Description.
	 */
	public String toString() {
		return "TestFactory: " + _suite.toString();
	}

	/*
	 * The <code>TestCache</code> class provides thread-local
	 * instances of a <code>TestSuite</code> class containing
	 * all tests defined in the <code>TestCase</code> class
	 * specified in the <code>TestFactory</code>.
     */ 
	private final class TestCache {

		private final ThreadLocal _localCache = new ThreadLocal() {

			protected Object initialValue() {
				return new TestSuite(_testClass);
			}
		};
        
		/*
		 * Returns the <code>Test</code> instance local to the 
		 * calling thread.
		 *
		 * @return Thread-local <code>Test</code> instance.
		 */
		Test getTest() {
			return (Test)_localCache.get();
		}
	}
}

==> junitperf_1.8.orig.tar.gz: junitperf-1.8.orig/src/app/com/clarkware/junitperf/TestFactory.java <==
package com.clarkware.junitperf;

import junit.framework.Test;
import junit.framework.TestCase;
import junit.framework.TestResult;
import junit.framework.TestSuite;

/**
 * The <code>TestFactory</code> class creates thread-local 
 * <code>TestSuite</code> instances.
 * <p>
 * This factory class should be used in cases when a stateful test
 * is intended to be decorated by a <code>LoadTest</code>.  A stateful
 * test is defined as any test that defines test-specific state in
 * its <code>setUp()</code> method.
 * </p>
 * <p>
 * Use of the <code>TestFactory</code> ensures that each thread spawned
 * by a <code>LoadTest</code> contains its own <code>TestSuite</code>
 * instance containing all tests defined in the specified 
 * <code>TestCase</code> class.
 * </p>
 * <p>
 * A typical usage scenario is as follows:
 * <blockquote>
 * <pre>
 * Test factory = new TestFactory(YourTestCase.class);
 * LoadTest test = new LoadTest(factory, numberOfUsers, ...);
 * ...
 * </pre>
 * </blockquote>
 * </p>
 * <p>
 * Of course, static variables cannot be protected externally, so tests
 * intended to be run in a multi-threaded environment should ensure
 * that the use of static variables is thread-safe.
 * </p>
 * <p>
 * This class is dependent on Java 2.  For earlier platforms a 
 * local cache implementation should be changed to use, for example, 
 * a HashMap to track thread-local information.
 * </p>
 * @author <a href="mailto:mike@clarkware.com">Mike Clark</a>
 * @author <a href="http://www.clarkware.com">Clarkware Consulting, Inc.</a>
 * @author Ervin Varga
 *
 * @see junit.framework.Test
 * @see com.clarkware.junitperf.LoadTest
 */

public class TestFactory implements Test {
    
	protected final Class _testClass;
	private TestSuite _suite; 
	private final TestCache _testCache;
    
	/**
	 * Constructs a <code>TestFactory</code> instance.
	 *
	 * @param testClass The <code>TestCase</code> class to load test.
	 */
	public TestFactory(Class testClass) {

		if (!(TestCase.class.isAssignableFrom(testClass))) {
			throw new IllegalArgumentException("TestFactory must " +
				"be constructed with a TestCase class.");
		}

		_testClass = testClass;
		_testCache = new TestCache();
	}

	/**
	 * Runs an instance of the <code>Test</code> class and 
	 * collects its result in the specified <code>TestResult</code>. 
	 * <p>
	 * Each invocation of this method triggers the creation of a 
	 * new <code>Test</code> class instance as specified in the
	 * construction of this <code>TestFactory</code>.
	 *
	 * @param result Test result.
	 */
	public void run(TestResult result) {
		getTest().run(result);        
	}
    
	/**
	 * Returns the number of tests in this test.
	 *
	 * @return Number of tests.
	 */
	public int countTestCases() {
		return getTestSuite().countTestCases();
	}

	/**
	 * Returns the test description.
	 *
	 * @return Description.
	 */
	public String toString() {
		return "TestFactory: " + getTestSuite().toString();
	}
	
	protected Test getTest() {
		return _testCache.getTest();
	}
	
	protected TestSuite getTestSuite() {
		if (_suite == null) {
			_suite = makeTestSuite();
		}
		
		return _suite;
	}
	
	protected TestSuite makeTestSuite() {
		return new TestSuite(_testClass);
	}

	/*
	 * The <code>TestCache</code> class provides thread-local
	 * instances of a <code>TestSuite</code> class containing
	 * tests defined in the <code>TestCase</code> class
	 * specified in the <code>TestFactory</code>.
     */ 
	private final class TestCache {

		private final ThreadLocal _localCache = new ThreadLocal() {

			protected Object initialValue() {
				return makeTestSuite();
			}
		};
        
		/*
		 * Returns the <code>Test</code> instance local to the 
		 * calling thread.
		 *
		 * @return Thread-local <code>Test</code> instance.
		 */
		Test getTest() {
			return (Test)_localCache.get();
		}
	}
}
